# pytyped

`pytyped` is a collection of Python packages whose goal is to enable as much type-driven development as possible in Python.
We believe in using types to automate mundane and repetitive tasks.
Currently, `pytyped` includes:
- [pytyped-json](https://pypi.org/project/pytyped-json/) for automatic extraction of JSON decoders/encoders given a Python type.
- [pytyped-macros](https://pypi.org/project/pytyped-macros/) for a generalized automatic extraction engine given a Python type.
- [pytyped-metrics](https://pypi.org/project/pytyped-metrics/) for automatic extraction of metric exporters given a Python type.

### Installation

You can install `pytyped` from [PyPI](https://pypi.org/):

```
pip install pytyped
```

`pytyped` is checked on `Python 3.6+`.

### Issues

Please report any issues to the [GitHub repository for this package](https://github.com/stasharrofi/pytyped).

### Contributors

- [Shahab Tasharrofi](mailto:shahab.tasharrofi@gmail.com)
